This is a graph library which allows user to make a graph, plot the graph and also make a adjacency list and matrix of the graph.

A graph is a non-linear data structure consisting of vertices (V) and edges (E). The most commonly used representations of a graph are adjacency matrix (a 2D array of size V x V where V is the number of vertices in a graph) and adjacency list (an array of lists represents the list of vertices adjacent to each vertex).

An adjacency list is a collection of unordered lists used to represent a finite graph.

An adjacency matrix is a way of representing a graph as a matrix of booleans (0's and 1's). A finite graph can be represented in the form of a square matrix on a computer, where the boolean value of the matrix indicates if there is a direct path between two vertices.

This library is made for the college project and is not made for any industrial project. If this library is related to any of the hosted library it is completely coincidental.